@@ -290,18 +290,10 @@ static void sat_draw(GtkWidget *widget, cache_context_t *context) {
     int i, x;
     int swid = (width-SAT_SPACING*(sat->num-1))/sat->num;
 
-#if 0
-    int max_ss = 1;
-    for(i=0;i<sat->num;i++)
-      if(sat->ss[i] > max_ss) max_ss = sat->ss[i];
-
-    printf("max_ss = %d dB\n", max_ss);
-#else
     /* as of xgps, a ss of 40 and more is "plenty" */
     int max_ss = 40;
     for(i=0;i<sat->num;i++)
       if(sat->ss[i] > max_ss) sat->ss[i] = max_ss;
-#endif    
 
     if(swid > 40) {
       swid = 40;
@@ -322,7 +314,8 @@ static void sat_draw(GtkWidget *widget, cache_context_t *context) {
 
       int tw, th;
       pango_layout_get_pixel_size(layout, &tw, &th);  
-      gdk_draw_layout(context->gotoc.sat_pixmap, widget->style->black_gc,
+      gdk_draw_layout(context->gotoc.sat_pixmap, 
+		      widget->style->text_gc[GTK_STATE_NORMAL],
 		      x + swid/2 - tw/2, height - th, layout);
 	
       g_object_unref(layout);
@@ -330,9 +323,8 @@ static void sat_draw(GtkWidget *widget, cache_context_t *context) {
       int h = (height-th) * sat->ss[i] / max_ss; 
 
       gdk_draw_rectangle(context->gotoc.sat_pixmap, 
-			 sat->used[i]?used_gc:widget->style->black_gc, 
-			 TRUE,
-			 x, height-h-th, swid, h);
+		 sat->used[i]?used_gc:widget->style->fg_gc[GTK_STATE_NORMAL], 
+		 TRUE, x, height-h-th, swid, h);
 
       x += SAT_SPACING+swid;
     }
@@ -342,10 +334,12 @@ static void sat_draw(GtkWidget *widget, cache_context_t *context) {
     free(sat->ss);
     free(sat->used);
   } else {
-    PangoLayout *layout = gtk_widget_create_pango_layout(widget, _("No SAT info"));
+    PangoLayout *layout = 
+      gtk_widget_create_pango_layout(widget, _("No SAT info"));
     int tw, th;
     pango_layout_get_pixel_size(layout, &tw, &th);  
-    gdk_draw_layout(context->gotoc.sat_pixmap, widget->style->black_gc,
+    gdk_draw_layout(context->gotoc.sat_pixmap, 
+		    widget->style->text_gc[GTK_STATE_NORMAL],
 		    (width - tw)/2, (height - th)/2, layout);
     
     g_object_unref(layout);
