@@ -241,7 +241,9 @@ pos_t *get_pos(appdata_t *appdata) {
 }
 
 void distance_str(char *str, int len, float dist, gboolean imperial) {
-  if(imperial) {
+  if(isnan(dist))
+    snprintf(str, len, "---");
+  else if(imperial) {
     /* 1 mil = 1760 yd = 5280 ft ... */
     if(dist<0.018)      snprintf(str, len, "%.1f ft", dist*5280.0);
     else if(dist<0.055) snprintf(str, len, "%.1f yd", dist*1760.0);
